aboutsummaryrefslogtreecommitdiffhomepage
path: root/model/entry.go
diff options
context:
space:
mode:
Diffstat (limited to 'model/entry.go')
-rw-r--r--model/entry.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/model/entry.go b/model/entry.go
index 79a3bcb..f9a9638 100644
--- a/model/entry.go
+++ b/model/entry.go
@@ -15,7 +15,7 @@ const (
EntryStatusRead = "read"
EntryStatusRemoved = "removed"
DefaultSortingOrder = "published_at"
- DefaultSortingDirection = "desc"
+ DefaultSortingDirection = "asc"
)
// Entry represents a feed item in the system.
@@ -81,8 +81,8 @@ func ValidateRange(offset, limit int) error {
return nil
}
-// GetOppositeDirection returns the opposite sorting direction.
-func GetOppositeDirection(direction string) string {
+// OppositeDirection returns the opposite sorting direction.
+func OppositeDirection(direction string) string {
if direction == "asc" {
return "desc"
}